import { NonNullablePaths } from '@wix/sdk-types';

/** Automation */
interface Automation {
    /**
     * Automation ID
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /** Revision */
    revision?: string | null;
    /**
     * Automation name
     * @maxLength 500
     */
    name?: string;
    /**
     * Automation description
     * @maxLength 2000
     */
    description?: string;
    /**
     * Automation Type
     * @readonly
     */
    type?: TypeWithLiterals;
    /** Automation Status */
    status?: StatusWithLiterals;
    /** Rule that contains a trigger and some actions */
    rule?: Rule;
    /**
     * Source Application Automation
     * @readonly
     */
    source?: Source;
    /**
     * Metadata
     * @readonly
     */
    metadata?: AutomationMetadata;
    /**
     * Created date
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Updated date
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * ESB Configuration ID
     * @format GUID
     * @readonly
     */
    esbConfigurationId?: string | null;
    /**
     * Was this automation migrated from v1
     * @readonly
     */
    migratedFromV1?: boolean | null;
    /** @readonly */
    migratedToV3?: boolean | null;
}
declare enum Type {
    CUSTOM = "CUSTOM",
    APPLICATION = "APPLICATION"
}
/** @enumType */
type TypeWithLiterals = Type | 'CUSTOM' | 'APPLICATION';
declare enum Status {
    ACTIVE = "ACTIVE",
    INACTIVE = "INACTIVE"
}
/** @enumType */
type StatusWithLiterals = Status | 'ACTIVE' | 'INACTIVE';
interface Rule {
    /** an event triggered by visitors on a site, or by a site manager (owner & team). */
    trigger?: Trigger;
    /**
     * the actions responding to the trigger happening.
     * ** IMPORTANT NOTE: the order of the actions is important, and will be executed in the order they appear in the list **
     * @minSize 1
     * @maxSize 30
     */
    actions?: Action[];
}
interface Trigger {
    /**
     * the id of the app defining the trigger
     * @format GUID
     */
    appId?: string;
    /**
     * Identifier for this trigger - human readable action key
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
    /**
     * optional list of filters on schema fields
     * @maxSize 5
     */
    filters?: Filter[];
    /**
     * optional - allows to define a trigger whose following actions will be executed only if the same event for the same resource has not in the last X seconds.
     * for example, if the trigger is "session booked", the resource is a contact and the timeframe is 3600 seconds (contact hasn't booked another session in the last hour),
     * then the actions will be executed only if the same event (session booked for that contact) has not happened in the last hour.
     */
    debounce?: Debounce;
}
interface Filter {
    /**
     * the filter identifier
     * @format GUID
     */
    _id?: string | null;
    /**
     * the field key from the schema, for example "formId"
     * @minLength 1
     * @maxLength 110
     */
    fieldKey?: string;
    /**
     * filter expression that evaluates to a boolean, for example - {{ contains(["guid1","guid2"];formId) }}
     * @minLength 5
     */
    filterExpression?: string;
}
interface Debounce {
    /**
     * Amount of time in seconds to wait for any additional events to occur before triggering the actions.
     * If no additional events occur within the specified time, the actions will be triggered.
     * If additional events occur within the specified time, the timer will be reset.
     * @min 1
     */
    timeFrameInSeconds?: number;
    /**
     * The field key in the trigger's payload of the entity/event to debounce on
     * For example: if the trigger is "user logged in", the resource is a contact and the resource key is "contactId",
     * Another example: if the trigger is "visitor logged in", the resource is a visitor and the resource key is "visitorId".
     * @minLength 1
     * @maxLength 110
     */
    fieldKey?: string;
}
interface Action {
    /**
     * the id of the action for delayed events
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * the id of the app defining the action
     * @format GUID
     */
    appId?: string;
    /**
     * Identifier for this action - human readable action key - unique per app def id
     * @maxLength 80
     */
    actionKey?: string;
    /**
     * input mapping expression for the action inputs
     * for example:
     * `{  "subject": "Thanks for reaching out!"
     * "message": "Hi {{contact.name.first}}, thanks for contacting our business"
     * }`
     * where the value for "contact.name.first" comes from the trigger's payload
     * @maxLength 20000
     */
    actionConfig?: string;
    /**
     * output mapping expression for the action output
     * for example in get-contact action:
     * `{ "author": "{{$}}" }`
     * This will map the entire entity of contact under `author` namespace
     * @maxLength 3000
     */
    outputActionConfig?: string | null;
    /** Optional delay configuration for the action */
    delay?: Delay;
    /** allows you define an activation policy - like number of activations in a time frame, or limit by some identifier, like contact (e.g. send email to user only at first login) */
    rateLimit?: RateLimit;
    /**
     * allows the user to define a condition for the action to be executed, if the condition fails the action (and following actions) will not be executed
     * @deprecated allows the user to define a condition for the action to be executed, if the condition fails the action (and following actions) will not be executed
     * @replacedBy conditions
     * @targetRemovalDate 2023-08-01
     */
    condition?: Condition;
    conditions?: Conditions;
    /**
     * allows the user to define a namespace for the action output
     * @minLength 1
     * @maxLength 100
     */
    namespace?: string | null;
}
declare enum BlockType {
    UNKNOWN = "UNKNOWN",
    OR = "OR",
    AND = "AND"
}
/** @enumType */
type BlockTypeWithLiterals = BlockType | 'UNKNOWN' | 'OR' | 'AND';
interface ConditionBlock {
    type?: BlockTypeWithLiterals;
    /**
     * @minSize 1
     * @maxSize 20
     */
    lineExpressions?: string[];
}
interface Offset extends OffsetValueOneOf {
    /** A delay in seconds */
    seconds?: number;
    /** The key of the field in the trigger payload which contains a delay, in seconds. */
    delayFieldKey?: string;
}
/** @oneof */
interface OffsetValueOneOf {
    /** A delay in seconds */
    seconds?: number;
    /** The key of the field in the trigger payload which contains a delay, in seconds. */
    delayFieldKey?: string;
}
/** calculated as date + delay */
interface Until {
    /** The key of the field in the trigger payload which contains the date to delay until */
    dateFieldKey?: string;
    /** Optional: a delay to add together with the date described in the payload */
    offset?: Offset;
}
interface Delay extends DelayTypeOneOf {
    /** A delay which is calculated based on the immediate time when the action is triggered. */
    for?: Offset;
    /** A delay which is calculated based on a date field in the trigger payload. May also be used together with an Offset delay. */
    until?: Until;
}
/** @oneof */
interface DelayTypeOneOf {
    /** A delay which is calculated based on the immediate time when the action is triggered. */
    for?: Offset;
    /** A delay which is calculated based on a date field in the trigger payload. May also be used together with an Offset delay. */
    until?: Until;
}
interface RateLimit {
    /**
     * time frame in minutes
     * @min 1
     */
    timeFrame?: number | null;
    /**
     * number of activations allowed in the given time frame
     * @min 1
     */
    activations?: number;
    /**
     * limit the activation by an entity, for example activate once per contact. example: {{contact.id}}
     * @minLength 1
     * @maxLength 300
     */
    uniqueIdentifierExpression?: string | null;
}
interface Condition {
    /**
     * entity object is deprecated due to the new approach to conditions
     * the condition expression, for example - {{and(gt(price;10);lt(price;100))}}
     * @minLength 1
     * @maxLength 2000
     */
    conditionExpression?: string;
}
interface Conditions {
    /**
     * condition evaluates to `true` if either of the blocks evaluate to `true` (aka OR between all)
     * @minSize 1
     * @maxSize 10
     */
    conditionBlocks?: ConditionBlock[];
}
interface Source {
    /** Automation ID */
    automationId?: string | null;
    /** Application ID */
    appId?: string | null;
    /** Component ID */
    componentId?: string | null;
    /** Version */
    version?: number | null;
}
interface AutomationMetadata {
    /** Is this Automation hidden on a site? */
    hidden?: boolean;
    /** Can this Automation be dismissed (inactivated) on a site? */
    alwaysActive?: boolean;
    /** Is this Automation's scheduling modification is disabled on a site? */
    schedulingModificationDisabled?: boolean;
    /** Is the removal of this Automation's actions disabled? */
    actionRemovalDisabled?: boolean;
    /** Is conditions editing for this Automation allowed on a site? */
    actionConditionsEditingDisabled?: boolean;
}
declare enum Domain {
    /** User domain (default) */
    USER = "USER",
    /** Wix domain */
    WIX = "WIX"
}
/** @enumType */
type DomainWithLiterals = Domain | 'USER' | 'WIX';
interface ExtendedFields {
    /**
     * Extended field data. Each key corresponds to the namespace of the app that created the extended fields.
     * The value of each key is structured according to the schema defined when the extended fields were configured.
     *
     * You can only access fields for which you have the appropriate permissions.
     *
     * Learn more about [extended fields](https://dev.wix.com/docs/rest/articles/getting-started/extended-fields).
     */
    namespaces?: Record<string, Record<string, any>>;
}
interface GetApplicationAutomationRequest {
    /**
     * Application Automation ID
     * @format GUID
     */
    automationId?: string;
}
interface GetApplicationAutomationResponse {
    /** Automation */
    automation?: Automation;
}
interface QueryApplicationAutomationsRequest {
    /** Query */
    query?: QueryV2;
}
interface QueryV2 extends QueryV2PagingMethodOneOf {
    /** Paging options to limit and offset the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object.
     *
     * Learn more about [filtering](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#filters).
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object.
     *
     * Learn more about [sorting](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#sorting).
     */
    sort?: Sorting[];
    /** Array of projected fields. A list of specific field names to return. If `fieldsets` are also specified, the union of `fieldsets` and `fields` is returned. */
    fields?: string[];
    /** Array of named, predefined sets of projected fields. A array of predefined named sets of fields to be returned. Specifying multiple `fieldsets` will return the union of fields from all sets. If `fields` are also specified, the union of `fieldsets` and `fields` is returned. */
    fieldsets?: string[];
}
/** @oneof */
interface QueryV2PagingMethodOneOf {
    /** Paging options to limit and offset the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface QueryApplicationAutomationsResponse {
    /** List of automations */
    automations?: Automation[];
    /** Paging metadata */
    paging?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface UpdateApplicationAutomationConfigurationIdRequest {
    /**
     * Application Automation ID
     * @format GUID
     */
    automationId?: string;
    /**
     * Configuration ID
     * @format GUID
     */
    esbConfigurationId?: string;
}
interface UpdateApplicationAutomationConfigurationIdResponse {
}
interface UpdateApplicationAutomationToMigratedFromV1Request {
    /**
     * Application Automation ID
     * @format GUID
     */
    automationId?: string;
    /**
     * Revision
     * @readonly
     */
    revision?: string | null;
    /** value to be set */
    value?: boolean | null;
}
interface UpdateApplicationAutomationToMigratedFromV1Response {
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface Empty {
}
interface MetaSiteSpecialEvent extends MetaSiteSpecialEventPayloadOneOf {
    /** Emitted on a meta site creation. */
    siteCreated?: SiteCreated;
    /** Emitted on a meta site transfer completion. */
    siteTransferred?: SiteTransferred;
    /** Emitted on a meta site deletion. */
    siteDeleted?: SiteDeleted;
    /** Emitted on a meta site restoration. */
    siteUndeleted?: SiteUndeleted;
    /** Emitted on the first* publish of the meta site (* switching from unpublished to published state). */
    sitePublished?: SitePublished;
    /** Emitted on a meta site unpublish. */
    siteUnpublished?: SiteUnpublished;
    /** Emitted when meta site is marked as template. */
    siteMarkedAsTemplate?: SiteMarkedAsTemplate;
    /** Emitted when meta site is marked as a WixSite. */
    siteMarkedAsWixSite?: SiteMarkedAsWixSite;
    /** Emitted when an application is provisioned (installed). */
    serviceProvisioned?: ServiceProvisioned;
    /** Emitted when an application is removed (uninstalled). */
    serviceRemoved?: ServiceRemoved;
    /** Emitted when meta site name (URL slug) is changed. */
    siteRenamedPayload?: SiteRenamed;
    /** Emitted when meta site was permanently deleted. */
    hardDeleted?: SiteHardDeleted;
    /** Emitted on a namespace change. */
    namespaceChanged?: NamespaceChanged;
    /** Emitted when Studio is attached. */
    studioAssigned?: StudioAssigned;
    /** Emitted when Studio is detached. */
    studioUnassigned?: StudioUnassigned;
    /**
     * Emitted when one of the URLs is changed. After this event you may call `urls-server` to fetch
     * the actual URL.
     *
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1732520791210559?thread_ts=1732027914.294059&cid=C0UHEBPFT
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1744115197619459
     */
    urlChanged?: SiteUrlChanged;
    /** Site is marked as PurgedExternally */
    sitePurgedExternally?: SitePurgedExternally;
    /** Emitted when Odeditor is attached. */
    odeditorAssigned?: OdeditorAssigned;
    /** Emitted when Odeditor is detached. */
    odeditorUnassigned?: OdeditorUnassigned;
    /** Emitted when Picasso is attached. */
    picassoAssigned?: PicassoAssigned;
    /** Emitted when Picasso is detached. */
    picassoUnassigned?: PicassoUnassigned;
    /**
     * A meta site id.
     * @format GUID
     */
    metaSiteId?: string;
    /** A meta site version. Monotonically increasing. */
    version?: string;
    /** A timestamp of the event. */
    timestamp?: string;
    /**
     * TODO(meta-site): Change validation once validations are disabled for consumers
     * More context: https://wix.slack.com/archives/C0UHEBPFT/p1720957844413149 and https://wix.slack.com/archives/CFWKX325T/p1728892152855659
     * @maxSize 4000
     */
    assets?: Asset[];
}
/** @oneof */
interface MetaSiteSpecialEventPayloadOneOf {
    /** Emitted on a meta site creation. */
    siteCreated?: SiteCreated;
    /** Emitted on a meta site transfer completion. */
    siteTransferred?: SiteTransferred;
    /** Emitted on a meta site deletion. */
    siteDeleted?: SiteDeleted;
    /** Emitted on a meta site restoration. */
    siteUndeleted?: SiteUndeleted;
    /** Emitted on the first* publish of the meta site (* switching from unpublished to published state). */
    sitePublished?: SitePublished;
    /** Emitted on a meta site unpublish. */
    siteUnpublished?: SiteUnpublished;
    /** Emitted when meta site is marked as template. */
    siteMarkedAsTemplate?: SiteMarkedAsTemplate;
    /** Emitted when meta site is marked as a WixSite. */
    siteMarkedAsWixSite?: SiteMarkedAsWixSite;
    /** Emitted when an application is provisioned (installed). */
    serviceProvisioned?: ServiceProvisioned;
    /** Emitted when an application is removed (uninstalled). */
    serviceRemoved?: ServiceRemoved;
    /** Emitted when meta site name (URL slug) is changed. */
    siteRenamedPayload?: SiteRenamed;
    /** Emitted when meta site was permanently deleted. */
    hardDeleted?: SiteHardDeleted;
    /** Emitted on a namespace change. */
    namespaceChanged?: NamespaceChanged;
    /** Emitted when Studio is attached. */
    studioAssigned?: StudioAssigned;
    /** Emitted when Studio is detached. */
    studioUnassigned?: StudioUnassigned;
    /**
     * Emitted when one of the URLs is changed. After this event you may call `urls-server` to fetch
     * the actual URL.
     *
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1732520791210559?thread_ts=1732027914.294059&cid=C0UHEBPFT
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1744115197619459
     */
    urlChanged?: SiteUrlChanged;
    /** Site is marked as PurgedExternally */
    sitePurgedExternally?: SitePurgedExternally;
    /** Emitted when Odeditor is attached. */
    odeditorAssigned?: OdeditorAssigned;
    /** Emitted when Odeditor is detached. */
    odeditorUnassigned?: OdeditorUnassigned;
    /** Emitted when Picasso is attached. */
    picassoAssigned?: PicassoAssigned;
    /** Emitted when Picasso is detached. */
    picassoUnassigned?: PicassoUnassigned;
}
interface Asset {
    /**
     * An application definition id (app_id in dev-center). For legacy reasons may be UUID or a string (from Java Enum).
     * @maxLength 36
     */
    appDefId?: string;
    /**
     * An instance id. For legacy reasons may be UUID or a string.
     * @maxLength 200
     */
    instanceId?: string;
    /** An application state. */
    state?: StateWithLiterals;
}
declare enum State {
    UNKNOWN = "UNKNOWN",
    ENABLED = "ENABLED",
    DISABLED = "DISABLED",
    PENDING = "PENDING",
    DEMO = "DEMO"
}
/** @enumType */
type StateWithLiterals = State | 'UNKNOWN' | 'ENABLED' | 'DISABLED' | 'PENDING' | 'DEMO';
interface SiteCreated {
    /**
     * A template identifier (empty if not created from a template).
     * @maxLength 36
     */
    originTemplateId?: string;
    /**
     * An account id of the owner.
     * @format GUID
     */
    ownerId?: string;
    /** A context in which meta site was created. */
    context?: SiteCreatedContextWithLiterals;
    /**
     * A meta site id from which this site was created.
     *
     * In case of a creation from a template it's a template id.
     * In case of a site duplication ("Save As" in dashboard or duplicate in UM) it's an id of a source site.
     * @format GUID
     */
    originMetaSiteId?: string | null;
    /**
     * A meta site name (URL slug).
     * @maxLength 20
     */
    siteName?: string;
    /** A namespace. */
    namespace?: NamespaceWithLiterals;
}
declare enum SiteCreatedContext {
    /** A valid option, we don't expose all reasons why site might be created. */
    OTHER = "OTHER",
    /** A meta site was created from template. */
    FROM_TEMPLATE = "FROM_TEMPLATE",
    /** A meta site was created by copying of the transfferred meta site. */
    DUPLICATE_BY_SITE_TRANSFER = "DUPLICATE_BY_SITE_TRANSFER",
    /** A copy of existing meta site. */
    DUPLICATE = "DUPLICATE",
    /** A meta site was created as a transfferred site (copy of the original), old flow, should die soon. */
    OLD_SITE_TRANSFER = "OLD_SITE_TRANSFER",
    /** deprecated A meta site was created for Flash editor. */
    FLASH = "FLASH"
}
/** @enumType */
type SiteCreatedContextWithLiterals = SiteCreatedContext | 'OTHER' | 'FROM_TEMPLATE' | 'DUPLICATE_BY_SITE_TRANSFER' | 'DUPLICATE' | 'OLD_SITE_TRANSFER' | 'FLASH';
declare enum Namespace {
    UNKNOWN_NAMESPACE = "UNKNOWN_NAMESPACE",
    /** Default namespace for UGC sites. MetaSites with this namespace will be shown in a user's site list by default. */
    WIX = "WIX",
    /** ShoutOut stand alone product. These are siteless (no actual Wix site, no HtmlWeb). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    SHOUT_OUT = "SHOUT_OUT",
    /** MetaSites created by the Albums product, they appear as part of the Albums app. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    ALBUMS = "ALBUMS",
    /** Part of the WixStores migration flow, a user tries to migrate and gets this site to view and if the user likes it then stores removes this namespace and deletes the old site with the old stores. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    WIX_STORES_TEST_DRIVE = "WIX_STORES_TEST_DRIVE",
    /** Hotels standalone (siteless). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    HOTELS = "HOTELS",
    /** Clubs siteless MetaSites, a club without a wix website. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    CLUBS = "CLUBS",
    /** A partially created ADI website. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    ONBOARDING_DRAFT = "ONBOARDING_DRAFT",
    /** AppBuilder for AppStudio / shmite (c). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    DEV_SITE = "DEV_SITE",
    /** LogoMaker websites offered to the user after logo purchase. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    LOGOS = "LOGOS",
    /** VideoMaker websites offered to the user after video purchase. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    VIDEO_MAKER = "VIDEO_MAKER",
    /** MetaSites with this namespace will *not* be shown in a user's site list by default. */
    PARTNER_DASHBOARD = "PARTNER_DASHBOARD",
    /** MetaSites with this namespace will *not* be shown in a user's site list by default. */
    DEV_CENTER_COMPANY = "DEV_CENTER_COMPANY",
    /**
     * A draft created by HTML editor on open. Upon "first save" it will be moved to be of WIX domain.
     *
     * Meta site with this namespace will *not* be shown in a user's site list by default.
     */
    HTML_DRAFT = "HTML_DRAFT",
    /**
     * the user-journey for Fitness users who want to start from managing their business instead of designing their website.
     * Will be accessible from Site List and will not have a website app.
     * Once the user attaches a site, the site will become a regular wixsite.
     */
    SITELESS_BUSINESS = "SITELESS_BUSINESS",
    /** Belongs to "strategic products" company. Supports new product in the creator's economy space. */
    CREATOR_ECONOMY = "CREATOR_ECONOMY",
    /** It is to be used in the Business First efforts. */
    DASHBOARD_FIRST = "DASHBOARD_FIRST",
    /** Bookings business flow with no site. */
    ANYWHERE = "ANYWHERE",
    /** Namespace for Headless Backoffice with no editor */
    HEADLESS = "HEADLESS",
    /**
     * Namespace for master site that will exist in parent account that will be referenced by subaccounts
     * The site will be used for account level CSM feature for enterprise
     */
    ACCOUNT_MASTER_CMS = "ACCOUNT_MASTER_CMS",
    /** Rise.ai Siteless account management for Gift Cards and Store Credit. */
    RISE = "RISE",
    /**
     * As part of the branded app new funnel, users now can create a meta site that will be branded app first.
     * There's a blank site behind the scene but it's blank).
     * The Mobile company will be the owner of this namespace.
     */
    BRANDED_FIRST = "BRANDED_FIRST",
    /** Nownia.com Siteless account management for Ai Scheduling Assistant. */
    NOWNIA = "NOWNIA",
    /**
     * UGC Templates are templates that are created by users for personal use and to sale to other users.
     * The Partners company owns this namespace.
     */
    UGC_TEMPLATE = "UGC_TEMPLATE",
    /** Codux Headless Sites */
    CODUX = "CODUX",
    /** Bobb - AI Design Creator. */
    MEDIA_DESIGN_CREATOR = "MEDIA_DESIGN_CREATOR",
    /**
     * Shared Blog Site is a unique single site across Enterprise account,
     * This site will hold all Blog posts related to the Marketing product.
     */
    SHARED_BLOG_ENTERPRISE = "SHARED_BLOG_ENTERPRISE",
    /** Standalone forms (siteless). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    STANDALONE_FORMS = "STANDALONE_FORMS",
    /** Standalone events (siteless). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    STANDALONE_EVENTS = "STANDALONE_EVENTS",
    /** MIMIR - Siteless account for MIMIR Ai Job runner. */
    MIMIR = "MIMIR"
}
/** @enumType */
type NamespaceWithLiterals = Namespace | 'UNKNOWN_NAMESPACE' | 'WIX' | 'SHOUT_OUT' | 'ALBUMS' | 'WIX_STORES_TEST_DRIVE' | 'HOTELS' | 'CLUBS' | 'ONBOARDING_DRAFT' | 'DEV_SITE' | 'LOGOS' | 'VIDEO_MAKER' | 'PARTNER_DASHBOARD' | 'DEV_CENTER_COMPANY' | 'HTML_DRAFT' | 'SITELESS_BUSINESS' | 'CREATOR_ECONOMY' | 'DASHBOARD_FIRST' | 'ANYWHERE' | 'HEADLESS' | 'ACCOUNT_MASTER_CMS' | 'RISE' | 'BRANDED_FIRST' | 'NOWNIA' | 'UGC_TEMPLATE' | 'CODUX' | 'MEDIA_DESIGN_CREATOR' | 'SHARED_BLOG_ENTERPRISE' | 'STANDALONE_FORMS' | 'STANDALONE_EVENTS' | 'MIMIR';
/** Site transferred to another user. */
interface SiteTransferred {
    /**
     * A previous owner id (user that transfers meta site).
     * @format GUID
     */
    oldOwnerId?: string;
    /**
     * A new owner id (user that accepts meta site).
     * @format GUID
     */
    newOwnerId?: string;
}
/** Soft deletion of the meta site. Could be restored. */
interface SiteDeleted {
    /** A deletion context. */
    deleteContext?: DeleteContext;
}
interface DeleteContext {
    /** When the meta site was deleted. */
    dateDeleted?: Date | null;
    /** A status. */
    deleteStatus?: DeleteStatusWithLiterals;
    /**
     * A reason (flow).
     * @maxLength 255
     */
    deleteOrigin?: string;
    /**
     * A service that deleted it.
     * @maxLength 255
     */
    initiatorId?: string | null;
}
declare enum DeleteStatus {
    UNKNOWN = "UNKNOWN",
    TRASH = "TRASH",
    DELETED = "DELETED",
    PENDING_PURGE = "PENDING_PURGE",
    PURGED_EXTERNALLY = "PURGED_EXTERNALLY"
}
/** @enumType */
type DeleteStatusWithLiterals = DeleteStatus | 'UNKNOWN' | 'TRASH' | 'DELETED' | 'PENDING_PURGE' | 'PURGED_EXTERNALLY';
/** Restoration of the meta site. */
interface SiteUndeleted {
}
/** First publish of a meta site. Or subsequent publish after unpublish. */
interface SitePublished {
}
interface SiteUnpublished {
    /**
     * A list of URLs previously associated with the meta site.
     * @maxLength 4000
     * @maxSize 10000
     */
    urls?: string[];
}
interface SiteMarkedAsTemplate {
}
interface SiteMarkedAsWixSite {
}
/**
 * Represents a service provisioned a site.
 *
 * Note on `origin_instance_id`:
 * There is no guarantee that you will be able to find a meta site using `origin_instance_id`.
 * This is because of the following scenario:
 *
 * Imagine you have a template where a third-party application (TPA) includes some stub data,
 * such as a product catalog. When you create a site from this template, you inherit this
 * default product catalog. However, if the template's product catalog is modified,
 * your site will retain the catalog as it was at the time of site creation. This ensures that
 * your site remains consistent with what you initially received and does not include any
 * changes made to the original template afterward.
 * To ensure this, the TPA on the template gets a new instance_id.
 */
interface ServiceProvisioned {
    /**
     * Either UUID or EmbeddedServiceType.
     * @maxLength 36
     */
    appDefId?: string;
    /**
     * Not only UUID. Something here could be something weird.
     * @maxLength 36
     */
    instanceId?: string;
    /**
     * An instance id from which this instance is originated.
     * @maxLength 36
     */
    originInstanceId?: string;
    /**
     * A version.
     * @maxLength 500
     */
    version?: string | null;
    /**
     * The origin meta site id
     * @format GUID
     */
    originMetaSiteId?: string | null;
}
interface ServiceRemoved {
    /**
     * Either UUID or EmbeddedServiceType.
     * @maxLength 36
     */
    appDefId?: string;
    /**
     * Not only UUID. Something here could be something weird.
     * @maxLength 36
     */
    instanceId?: string;
    /**
     * A version.
     * @maxLength 500
     */
    version?: string | null;
}
/** Rename of the site. Meaning, free public url has been changed as well. */
interface SiteRenamed {
    /**
     * A new meta site name (URL slug).
     * @maxLength 20
     */
    newSiteName?: string;
    /**
     * A previous meta site name (URL slug).
     * @maxLength 255
     */
    oldSiteName?: string;
}
/**
 * Hard deletion of the meta site.
 *
 * Could not be restored. Therefore it's desirable to cleanup data.
 */
interface SiteHardDeleted {
    /** A deletion context. */
    deleteContext?: DeleteContext;
}
interface NamespaceChanged {
    /** A previous namespace. */
    oldNamespace?: NamespaceWithLiterals;
    /** A new namespace. */
    newNamespace?: NamespaceWithLiterals;
}
/** Assigned Studio editor */
interface StudioAssigned {
}
/** Unassigned Studio editor */
interface StudioUnassigned {
}
/**
 * Fired in case site URLs were changed in any way: new secondary domain, published, account slug rename, site rename etc.
 *
 * This is an internal event, it's not propagated in special events, because it's non-actionable. If you need to keep up
 * with sites and its urls, you need to listen to another topic/event. Read about it:
 *
 * https://bo.wix.com/wix-docs/rest/meta-site/meta-site---urls-service
 */
interface SiteUrlChanged {
}
/**
 * Used at the end of the deletion flow for both draft sites and when a user deletes a site.
 * Consumed by other teams to remove relevant data.
 */
interface SitePurgedExternally {
    /**
     * @maxLength 2048
     * @maxSize 100
     * @deprecated
     * @targetRemovalDate 2025-04-15
     */
    appDefId?: string[];
}
/** Assigned Odeditor */
interface OdeditorAssigned {
}
/** Unassigned Odeditor */
interface OdeditorUnassigned {
}
/** Assigned Picasso editor */
interface PicassoAssigned {
}
/** Unassigned Picasso */
interface PicassoUnassigned {
}
interface SyncApplicationAutomationsRequest {
    /**
     * List of app IDs
     * @format GUID
     * @maxSize 20
     */
    appIds?: string[];
}
interface SyncApplicationAutomationsResponse {
}
interface BulkCreateApplicationAutomationRequest {
    /**
     * Automations to be created
     * @minSize 1
     */
    automations?: Automation[];
}
interface BulkCreateApplicationAutomationResponse {
    /** The created Automations */
    results?: Automation[];
    /** Bulk create metadata. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkActionMetadata {
    /** Number of items that were successfully processed. */
    totalSuccesses?: number;
    /** Number of items that couldn't be processed. */
    totalFailures?: number;
    /** Number of failures without details because detailed failure threshold was exceeded. */
    undetailedFailures?: number;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface CreateAutomationRequest {
    /** Automation to be created */
    automation: Automation;
}
interface CreateAutomationResponse {
    /** The created Automation */
    automation?: Automation;
}
interface MigrationBulkCreateAutomationsRequest {
    /** Automations to be created */
    automations?: Automation[];
    /** V1 Activity type (trigger name) */
    activityType?: string;
    /** automation id to counter map */
    automationIdToCounter?: Record<string, string>;
    /** automation id to last triggered map */
    automationIdToLastTriggered?: Record<string, string>;
    /** ignore validations */
    ignoreValidations?: boolean | null;
}
interface MigrationBulkCreateAutomationsResponse {
    /** bulk action metadata */
    bulkActionMetadata?: BulkActionMetadata;
    /** item metadata */
    itemMetadata?: ItemMetadata[];
}
interface ItemMetadata {
    /** Item ID. Should always be available, unless it's impossible (for example, when failing to create an item). */
    _id?: string | null;
    /** Index of the item within the request array. Allows for correlation between request and response items. */
    originalIndex?: number;
    /** Whether the requested action was successful for this item. When `false`, the `error` field is populated. */
    success?: boolean;
    /** Details about the error in case of failure. */
    error?: ApplicationError;
}
interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
interface MigrationBulkCreateAutomations {
    /**
     * Automations to be created
     * @maxSize 100
     */
    automations?: Automation[];
    /** V1 Activity type (trigger name) */
    activityType?: string;
    /** automation id to counter map */
    automationIdToCounter?: Record<string, string>;
    /** automation id to last triggered map */
    automationIdToLastTriggered?: Record<string, string>;
}
interface GetAutomationRequest {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    /** Automation type */
    automationType?: TypeWithLiterals;
}
interface GetAutomationResponse {
    /** Automation */
    automation?: Automation;
}
interface UpdateAutomationRequest {
    /** Automation to be updated, may be partial */
    automation: Automation;
}
interface UpdateAutomationResponse {
    /** The updated Automation */
    automation?: Automation;
}
interface UpdatedWithPreviousEntity {
    /** previous automation */
    previousAutomation?: Automation;
    /** updated automation */
    currentAutomation?: Automation;
}
interface MigrationUpdateAutomationRequest {
    /** Automation to be updated, may be partial */
    automation: Automation;
}
interface MigrationUpdateAutomationResponse {
    /** The updated Automation */
    automation?: Automation;
}
interface DeleteAutomationRequest {
    /**
     * Id of the Automation to delete
     * @format GUID
     */
    automationId: string;
    /** The revision of the Automation */
    revision?: string;
}
interface DeleteAutomationResponse {
}
interface DeletedWithEntity {
    /** Deleted automation */
    automation?: Automation;
}
interface QueryAutomationsRequest {
    /** WQL expression */
    query: QueryV2;
    /** Automation type */
    automationType?: TypeWithLiterals;
}
interface QueryAutomationsResponse {
    /** List of automations */
    automations?: Automation[];
    /** Paging metadata */
    paging?: PagingMetadataV2;
}
interface OverrideApplicationAutomationRequest {
    /** Application Automation */
    automation: Automation;
}
interface OverrideApplicationAutomationResponse {
    /** Custom Automation */
    automation?: Automation;
}
interface GenerateApplicationAutomationFromCustomRequest {
    /** Custom Automation */
    automation?: Automation;
}
interface GenerateApplicationAutomationFromCustomResponse {
    /** Application Automation */
    automation?: Automation;
}
interface ValidateAutomationByIdRequest {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    /** Automation type */
    automationType?: TypeWithLiterals;
}
interface ValidateAutomationByIdResponse {
    /** is the Automation valid */
    valid?: boolean;
    /**
     * list of validation errors for the automation Trigger
     * @maxSize 100
     */
    triggerValidationErrors?: TriggerValidationError[];
    /**
     * list of validation information for the automation Actions
     * @maxSize 100
     */
    actionValidationInfo?: ActionValidationInfo[];
}
interface TriggerValidationError extends TriggerValidationErrorErrorOneOf {
    /** trigger configuration error */
    configurationError?: TriggerConfigurationError;
    /** provider configuration error */
    providerConfigurationError?: ProviderConfigurationError;
    /** validation error type */
    errorType?: TriggerValidationErrorValidationErrorTypeWithLiterals;
}
/** @oneof */
interface TriggerValidationErrorErrorOneOf {
    /** trigger configuration error */
    configurationError?: TriggerConfigurationError;
    /** provider configuration error */
    providerConfigurationError?: ProviderConfigurationError;
}
declare enum TriggerValidationErrorValidationErrorType {
    UNKNOWN_VALIDATION_ERROR_TYPE = "UNKNOWN_VALIDATION_ERROR_TYPE",
    CONFIGURATION_ERROR = "CONFIGURATION_ERROR",
    PROVIDER_ERROR = "PROVIDER_ERROR"
}
/** @enumType */
type TriggerValidationErrorValidationErrorTypeWithLiterals = TriggerValidationErrorValidationErrorType | 'UNKNOWN_VALIDATION_ERROR_TYPE' | 'CONFIGURATION_ERROR' | 'PROVIDER_ERROR';
interface TriggerConfigurationError {
    /** trigger error type */
    errorType?: TriggerErrorTypeWithLiterals;
    /** optional - related filter field key */
    filterFieldKey?: string | null;
}
declare enum TriggerErrorType {
    UNKNOWN_TRIGGER_ERROR_TYPE = "UNKNOWN_TRIGGER_ERROR_TYPE",
    NOT_FOUND = "NOT_FOUND",
    APP_NOT_INSTALLED = "APP_NOT_INSTALLED",
    MODERATION_MISMATCH = "MODERATION_MISMATCH",
    DEPRECATED = "DEPRECATED",
    INVALID_TRIGGER_KEY = "INVALID_TRIGGER_KEY",
    INVALID_FILTER_FIELD_KEY = "INVALID_FILTER_FIELD_KEY",
    INVALID_FILTER_EXPRESSION = "INVALID_FILTER_EXPRESSION"
}
/** @enumType */
type TriggerErrorTypeWithLiterals = TriggerErrorType | 'UNKNOWN_TRIGGER_ERROR_TYPE' | 'NOT_FOUND' | 'APP_NOT_INSTALLED' | 'MODERATION_MISMATCH' | 'DEPRECATED' | 'INVALID_TRIGGER_KEY' | 'INVALID_FILTER_FIELD_KEY' | 'INVALID_FILTER_EXPRESSION';
interface ProviderConfigurationError {
    /** Key corresponding to the field in the schema. */
    fieldKey?: string | null;
    /** Error message. */
    message?: string;
    /** Label for a call-to-action button that's displayed with the error. Translated according to the SPI language context. */
    ctaLabel?: string | null;
    /** URL to redirect to when the call-to-action button is clicked. */
    ctaUrl?: string | null;
    /** Title for the error. */
    title?: string;
}
interface ActionValidationInfo {
    /**
     * the id of the action in the automation
     * @format GUID
     */
    actionId?: string | null;
    /**
     * the id of the app defining the action
     * @format GUID
     */
    appId?: string;
    /** human readable identifier of the action per app */
    actionKey?: string;
    /**
     * list of action validation errors
     * @maxSize 100
     */
    validationErrors?: ActionValidationError[];
}
interface ActionValidationError extends ActionValidationErrorErrorOneOf {
    /** action configuration error */
    configurationError?: ActionConfigurationError;
    /** provider configuration error */
    providerConfigurationError?: ProviderConfigurationError;
    /** validation error type */
    errorType?: ValidationErrorTypeWithLiterals;
}
/** @oneof */
interface ActionValidationErrorErrorOneOf {
    /** action configuration error */
    configurationError?: ActionConfigurationError;
    /** provider configuration error */
    providerConfigurationError?: ProviderConfigurationError;
}
declare enum ValidationErrorType {
    UNKNOWN_VALIDATION_ERROR_TYPE = "UNKNOWN_VALIDATION_ERROR_TYPE",
    CONFIGURATION_ERROR = "CONFIGURATION_ERROR",
    PROVIDER_ERROR = "PROVIDER_ERROR"
}
/** @enumType */
type ValidationErrorTypeWithLiterals = ValidationErrorType | 'UNKNOWN_VALIDATION_ERROR_TYPE' | 'CONFIGURATION_ERROR' | 'PROVIDER_ERROR';
interface ActionConfigurationError {
    /** action error type */
    errorType?: ActionErrorTypeWithLiterals;
    /** optional - related field key */
    fieldKey?: string | null;
}
declare enum ActionErrorType {
    UNKNOWN_ACTION_ERROR_TYPE = "UNKNOWN_ACTION_ERROR_TYPE",
    NOT_FOUND = "NOT_FOUND",
    APP_NOT_INSTALLED = "APP_NOT_INSTALLED",
    MODERATION_MISMATCH = "MODERATION_MISMATCH",
    DEPRECATED = "DEPRECATED",
    INVALID_ACTION_KEY = "INVALID_ACTION_KEY",
    INVALID_INPUT_MAPPING = "INVALID_INPUT_MAPPING",
    INVALID_OUTPUT_MAPPING = "INVALID_OUTPUT_MAPPING",
    INVALID_DELAY = "INVALID_DELAY",
    INVALID_RATE_LIMIT = "INVALID_RATE_LIMIT",
    INPUT_MAPPING_TYPE_MISMATCH = "INPUT_MAPPING_TYPE_MISMATCH",
    INPUT_MAPPING_MISSING_REQUIRED_FIELD = "INPUT_MAPPING_MISSING_REQUIRED_FIELD",
    INPUT_MAPPING_SCHEMA_MISMATCH = "INPUT_MAPPING_SCHEMA_MISMATCH",
    INPUT_MAPPING_VARIABLE_MISSING_FROM_SCHEMA = "INPUT_MAPPING_VARIABLE_MISSING_FROM_SCHEMA"
}
/** @enumType */
type ActionErrorTypeWithLiterals = ActionErrorType | 'UNKNOWN_ACTION_ERROR_TYPE' | 'NOT_FOUND' | 'APP_NOT_INSTALLED' | 'MODERATION_MISMATCH' | 'DEPRECATED' | 'INVALID_ACTION_KEY' | 'INVALID_INPUT_MAPPING' | 'INVALID_OUTPUT_MAPPING' | 'INVALID_DELAY' | 'INVALID_RATE_LIMIT' | 'INPUT_MAPPING_TYPE_MISMATCH' | 'INPUT_MAPPING_MISSING_REQUIRED_FIELD' | 'INPUT_MAPPING_SCHEMA_MISMATCH' | 'INPUT_MAPPING_VARIABLE_MISSING_FROM_SCHEMA';
interface ValidateAutomationRequest {
    /** Automation to validate */
    automation: Automation;
}
interface ValidateAutomationResponse {
    /** is the Automation valid */
    valid?: boolean;
    /**
     * list of validation errors for the automation Trigger
     * @maxSize 100
     */
    triggerValidationErrors?: TriggerValidationError[];
    /**
     * list of validation information for the automation Actions
     * @maxSize 100
     */
    actionValidationInfo?: ActionValidationInfo[];
}
interface UpdatedAutomationsWithEsb {
    /**
     * updated automations
     * @maxSize 100
     */
    automations?: Automation[];
}
interface GetAutomationActivationReportsRequest {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    paging?: Paging;
    /** Fields projection - pass in the field key you want to get back */
    fields?: string[];
}
interface GetAutomationActivationReportsResponse {
    /** Automation activation reports */
    activationReports?: ActivationReport[];
    metadata?: PagingMetadata;
    /** activationStatus -> count */
    stats?: Record<string, number>;
}
interface ActivationReport {
    /** @format GUID */
    activationId?: string;
    requestId?: string;
    status?: ActivationStatusWithLiterals;
    creationDate?: Date | null;
    updateDate?: Date | null;
    /** will be populated when status = FAILED */
    error?: string | null;
}
declare enum ActivationStatus {
    UNKNOWN_ACTIVATION_REQUEST = "UNKNOWN_ACTIVATION_REQUEST",
    IN_PROGRESS = "IN_PROGRESS",
    SUCCESS = "SUCCESS",
    FAILED = "FAILED",
    SCHEDULED = "SCHEDULED",
    RETRY = "RETRY",
    RESUMED = "RESUMED",
    PAUSED = "PAUSED"
}
/** @enumType */
type ActivationStatusWithLiterals = ActivationStatus | 'UNKNOWN_ACTIVATION_REQUEST' | 'IN_PROGRESS' | 'SUCCESS' | 'FAILED' | 'SCHEDULED' | 'RETRY' | 'RESUMED' | 'PAUSED';
interface PagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
}
interface GetAutomationActionSchemaRequest {
    /**
     * Automation's Configuration ID
     * @format GUID
     */
    esbConfigurationId?: string;
    /**
     * Specific action ID
     * @format GUID
     */
    actionId?: string;
}
interface GetAutomationActionSchemaResponse {
    /** The payload schema of the automation for the specific action */
    schema?: Record<string, any> | null;
}
interface GetActionsQuotaInfoRequest {
}
interface GetActionsQuotaInfoResponse {
    /** list of action quota information */
    actionProviderQuotaInfo?: ActionProviderQuotaInfo[];
}
interface ActionProviderQuotaInfo {
    /**
     * action app id
     * @format GUID
     */
    appId?: string;
    /**
     * the action key
     * @minLength 1
     * @maxLength 80
     */
    actionKey?: string;
    /** the action quota information */
    actionQuotaInfo?: ActionQuotaInfo;
}
interface ActionQuotaInfo {
    /**
     * Whether the quotas for your action are enforced. If you mark this as `true` in the response body,
     * Wix displays the information in the quota object on the site dashboard. If you mark this as `false` for
     * a user, Wix does not display any quota info on the site dashboard for your service.
     */
    enforced?: boolean;
    /**
     * The plans your service provides, together with the quotas enforced by each plan. A site may be enrolled
     * in multiple plans. Plans and quotas can be related as follows:
     *
     * + A single plan has a single quota.
     * + A single plan has multiple quotas.
     * + Multiple plans are associated with multiple quotas.
     *
     * Plans and quotas that are related should be grouped together in a single `quotaInfo`
     * object.
     */
    quotaInfo?: QuotaInfo[];
}
interface QuotaInfo {
    /** List of plans associated with the site making the request. */
    plans?: Plan[];
    /**
     * List of quotas associated with the plans the site is enrolled in.
     * @minSize 1
     */
    quotas?: Quota[];
    /**
     * Details for an upgrade call-to-action button.
     * Displayed in the Wix user’s site dashboard together with the quota details.
     */
    upgradeCta?: UpgradeCTA;
}
interface Plan {
    /** Plan ID defined by the action provider. */
    _id?: string;
    /** Plan name to display in the Wix user’s site dashboard. */
    name?: string;
}
interface Quota {
    /**
     * Name of the feature the quota is related to. For example, "Messages sent".
     * @minLength 1
     */
    featureName?: string;
    /**
     * Quota renewal date in [ISO 8601](https://www.iso.org/iso-8601-date-and-time-format.html) format.
     * For example, 10 July 2020 at 15:00 is written as `2020-07-10 15:00:00.000`.
     */
    renewalDate?: Date | null;
    /** The user's current quota usage. */
    currentUsage?: string;
    /** Quota limit data. */
    limit?: string | null;
    /** Additional information about the quota. Displayed as a tooltip in the Wix user’s dashboard. */
    additionalInfo?: AdditionalInfo;
}
interface CTA {
    /**
     * Call-to-action redirect URL.
     * @minLength 1
     */
    url?: string;
    /**
     * Call-to-action label.
     * @minLength 1
     */
    label?: string;
}
interface AdditionalInfo {
    /**
     * Tooltip content.
     * @minLength 1
     */
    description?: string;
    /** Details for an options call-to-action link that appears in the tooltip. */
    cta?: CTA;
}
interface UpgradeCTA {
    /**
     * CTA button redirect URL.
     * @minLength 1
     */
    url?: string;
    /**
     * CTA button label.
     * @minLength 1
     */
    label?: string;
}
interface BulkDeleteAutomationsRequest {
    /**
     * Automation IDs to delete
     * @format GUID
     * @maxSize 200
     */
    automationIds?: string[];
}
interface BulkDeleteAutomationsResponse {
}
interface GenerateActionInputMappingFromTemplateRequest {
    /** action app id */
    appId: string;
    /** the action key */
    actionKey: string;
    /** action input mapping template the action spi provider will generate input mapping from */
    actionInputMappingTemplate: Record<string, any> | null;
}
interface GenerateActionInputMappingFromTemplateResponse {
    /** generated action input mapping */
    generatedActionInputMapping?: Record<string, any> | null;
}
interface MigrationUpdateMigratedToV3AutomationRequest {
    /**
     * Automation id
     * @format GUID
     */
    automationId?: string;
}
interface MigrationUpdateMigratedToV3AutomationResponse {
}
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface AutomationCreatedEnvelope {
    entity: Automation;
    metadata: EventMetadata;
}
/** @webhook
 * @eventType wix.automations.v1.automation_created
 * @serviceIdentifier wix.automations.app_automations.v1.ApplicationAutomationsService
 * @slug created
 * @documentationMaturity preview
 */
declare function onAutomationCreated(handler: (event: AutomationCreatedEnvelope) => void | Promise<void>): void;
interface AutomationDeletedEnvelope {
    metadata: EventMetadata;
}
/** @webhook
 * @eventType wix.automations.v1.automation_deleted
 * @serviceIdentifier wix.automations.app_automations.v1.ApplicationAutomationsService
 * @slug deleted
 * @documentationMaturity preview
 */
declare function onAutomationDeleted(handler: (event: AutomationDeletedEnvelope) => void | Promise<void>): void;
interface AutomationUpdatedEnvelope {
    entity: Automation;
    metadata: EventMetadata;
}
/** @webhook
 * @eventType wix.automations.v1.automation_updated
 * @serviceIdentifier wix.automations.app_automations.v1.ApplicationAutomationsService
 * @slug updated
 * @documentationMaturity preview
 */
declare function onAutomationUpdated(handler: (event: AutomationUpdatedEnvelope) => void | Promise<void>): void;
interface AutomationDeletedWithEntityEnvelope {
    data: DeletedWithEntity;
    metadata: EventMetadata;
}
/** @webhook
 * @eventType wix.automations.v1.automation_deleted_with_entity
 * @serviceIdentifier com.wixpress.automations.service.AutomationsService
 * @slug deleted_with_entity
 * @documentationMaturity preview
 */
declare function onAutomationDeletedWithEntity(handler: (event: AutomationDeletedWithEntityEnvelope) => void | Promise<void>): void;
interface AutomationUpdatedWithPreviousEntityEnvelope {
    data: UpdatedWithPreviousEntity;
    metadata: EventMetadata;
}
/** @webhook
 * @eventType wix.automations.v1.automation_updated_with_previous_entity
 * @serviceIdentifier com.wixpress.automations.service.AutomationsService
 * @slug updated_with_previous_entity
 * @documentationMaturity preview
 */
declare function onAutomationUpdatedWithPreviousEntity(handler: (event: AutomationUpdatedWithPreviousEntityEnvelope) => void | Promise<void>): void;
type AutomationNonNullablePaths = `name` | `description` | `type` | `status` | `rule.trigger.appId` | `rule.trigger.triggerKey` | `rule.trigger.filters` | `rule.trigger.filters.${number}.fieldKey` | `rule.trigger.filters.${number}.filterExpression` | `rule.trigger.debounce.timeFrameInSeconds` | `rule.trigger.debounce.fieldKey` | `rule.actions` | `rule.actions.${number}.appId` | `rule.actions.${number}.actionKey` | `rule.actions.${number}.actionConfig` | `rule.actions.${number}.delay.for.seconds` | `rule.actions.${number}.delay.for.delayFieldKey` | `rule.actions.${number}.delay.until.dateFieldKey` | `rule.actions.${number}.rateLimit.activations` | `rule.actions.${number}.condition.conditionExpression` | `metadata.hidden` | `metadata.alwaysActive` | `metadata.schedulingModificationDisabled` | `metadata.actionRemovalDisabled` | `metadata.actionConditionsEditingDisabled`;
/**
 * Creates a new Automation
 * @param automation - Automation to be created
 * @public
 * @documentationMaturity preview
 * @requiredField automation
 * @requiredField automation.name
 * @requiredField automation.rule
 * @requiredField automation.rule.actions
 * @requiredField automation.rule.actions.actionKey
 * @requiredField automation.rule.actions.appId
 * @requiredField automation.rule.trigger
 * @requiredField automation.rule.trigger.appId
 * @requiredField automation.rule.trigger.triggerKey
 * @permissionId AUTOMATIONS.AUTOMATION_CREATE
 * @applicableIdentity APP
 * @returns The created Automation
 * @fqn com.wixpress.automations.service.AutomationsService.CreateAutomation
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function createAutomation(automation: NonNullablePaths<Automation, `name` | `rule` | `rule.actions` | `rule.actions.${number}.actionKey` | `rule.actions.${number}.appId` | `rule.trigger` | `rule.trigger.appId` | `rule.trigger.triggerKey`>): Promise<NonNullablePaths<Automation, AutomationNonNullablePaths>>;
/**
 * Get a Automation by id
 * @param automationId - Automation ID
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @applicableIdentity APP
 * @returns Automation
 * @fqn com.wixpress.automations.service.AutomationsService.GetAutomation
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function getAutomation(automationId: string, options?: GetAutomationOptions): Promise<NonNullablePaths<Automation, AutomationNonNullablePaths>>;
interface GetAutomationOptions {
    /** Automation type */
    automationType?: TypeWithLiterals;
}
/**
 * Update a Automation, supports partial update
 * Pass the latest `revision` for a successful update
 * @param _id - Automation ID
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField automation
 * @requiredField automation.revision
 * @permissionId AUTOMATIONS.AUTOMATION_UPDATE
 * @applicableIdentity APP
 * @returns The updated Automation
 * @fqn com.wixpress.automations.service.AutomationsService.UpdateAutomation
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function updateAutomation(_id: string, automation: NonNullablePaths<UpdateAutomation, `revision`>): Promise<NonNullablePaths<Automation, AutomationNonNullablePaths>>;
interface UpdateAutomation {
    /**
     * Automation ID
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /** Revision */
    revision?: string | null;
    /**
     * Automation name
     * @maxLength 500
     */
    name?: string;
    /**
     * Automation description
     * @maxLength 2000
     */
    description?: string;
    /**
     * Automation Type
     * @readonly
     */
    type?: TypeWithLiterals;
    /** Automation Status */
    status?: StatusWithLiterals;
    /** Rule that contains a trigger and some actions */
    rule?: Rule;
    /**
     * Source Application Automation
     * @readonly
     */
    source?: Source;
    /**
     * Metadata
     * @readonly
     */
    metadata?: AutomationMetadata;
    /**
     * Created date
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Updated date
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * ESB Configuration ID
     * @format GUID
     * @readonly
     */
    esbConfigurationId?: string | null;
    /**
     * Was this automation migrated from v1
     * @readonly
     */
    migratedFromV1?: boolean | null;
    /** @readonly */
    migratedToV3?: boolean | null;
}
/** @param _id - Automation ID
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField automation
 * @permissionId AUTOMATIONS.AUTOMATION_UPDATE
 * @applicableIdentity APP
 * @fqn com.wixpress.automations.service.AutomationsService.MigrationUpdateAutomation
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function migrationUpdateAutomation(_id: string, automation: MigrationUpdateAutomation): Promise<NonNullablePaths<MigrationUpdateAutomationResponse, {
    [P in AutomationNonNullablePaths]: `automation.${P}`;
}[AutomationNonNullablePaths]>>;
interface MigrationUpdateAutomation {
    /**
     * Automation ID
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /** Revision */
    revision?: string | null;
    /**
     * Automation name
     * @maxLength 500
     */
    name?: string;
    /**
     * Automation description
     * @maxLength 2000
     */
    description?: string;
    /**
     * Automation Type
     * @readonly
     */
    type?: TypeWithLiterals;
    /** Automation Status */
    status?: StatusWithLiterals;
    /** Rule that contains a trigger and some actions */
    rule?: Rule;
    /**
     * Source Application Automation
     * @readonly
     */
    source?: Source;
    /**
     * Metadata
     * @readonly
     */
    metadata?: AutomationMetadata;
    /**
     * Created date
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Updated date
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * ESB Configuration ID
     * @format GUID
     * @readonly
     */
    esbConfigurationId?: string | null;
    /**
     * Was this automation migrated from v1
     * @readonly
     */
    migratedFromV1?: boolean | null;
    /** @readonly */
    migratedToV3?: boolean | null;
}
/**
 * Delete an Automation
 * @param automationId - Id of the Automation to delete
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.AUTOMATION_DELETE
 * @applicableIdentity APP
 * @fqn com.wixpress.automations.service.AutomationsService.DeleteAutomation
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function deleteAutomation(automationId: string, options?: DeleteAutomationOptions): Promise<void>;
interface DeleteAutomationOptions {
    /** The revision of the Automation */
    revision?: string;
}
/**
 * Query Automations using [WQL - Wix Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language)
 * @public
 * @documentationMaturity preview
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @applicableIdentity APP
 * @fqn com.wixpress.automations.service.AutomationsService.QueryAutomations
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function queryAutomations(options?: QueryAutomationsOptions): AutomationsQueryBuilder;
interface QueryAutomationsOptions {
    /** Automation type */
    automationType?: TypeWithLiterals | undefined;
}
interface QueryCursorResult {
    cursors: Cursors;
    hasNext: () => boolean;
    hasPrev: () => boolean;
    length: number;
    pageSize: number;
}
interface AutomationsQueryResult extends QueryCursorResult {
    items: Automation[];
    query: AutomationsQueryBuilder;
    next: () => Promise<AutomationsQueryResult>;
    prev: () => Promise<AutomationsQueryResult>;
}
interface AutomationsQueryBuilder {
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    eq: (propertyName: '_id' | 'revision' | 'name' | 'description' | 'type' | 'status' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'source.version' | 'metadata.hidden' | 'metadata.alwaysActive' | 'metadata.schedulingModificationDisabled' | 'metadata.actionRemovalDisabled' | 'metadata.actionConditionsEditingDisabled' | '_createdDate' | '_updatedDate' | 'esbConfigurationId', value: any) => AutomationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    ne: (propertyName: '_id' | 'revision' | 'name' | 'description' | 'type' | 'status' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'source.version' | 'metadata.hidden' | 'metadata.alwaysActive' | 'metadata.schedulingModificationDisabled' | 'metadata.actionRemovalDisabled' | 'metadata.actionConditionsEditingDisabled' | '_createdDate' | '_updatedDate' | 'esbConfigurationId', value: any) => AutomationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    ge: (propertyName: '_id' | 'revision' | 'name' | 'description' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'source.version' | '_createdDate' | '_updatedDate' | 'esbConfigurationId', value: any) => AutomationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    gt: (propertyName: '_id' | 'revision' | 'name' | 'description' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'source.version' | '_createdDate' | '_updatedDate' | 'esbConfigurationId', value: any) => AutomationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    le: (propertyName: '_id' | 'revision' | 'name' | 'description' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'source.version' | '_createdDate' | '_updatedDate' | 'esbConfigurationId', value: any) => AutomationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    lt: (propertyName: '_id' | 'revision' | 'name' | 'description' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'source.version' | '_createdDate' | '_updatedDate' | 'esbConfigurationId', value: any) => AutomationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `string`.
     * @param string - String to compare against. Case-insensitive.
     * @documentationMaturity preview
     */
    startsWith: (propertyName: '_id' | 'name' | 'description' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'esbConfigurationId', value: string) => AutomationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `values`.
     * @param values - List of values to compare against.
     * @documentationMaturity preview
     */
    hasSome: (propertyName: '_id' | 'revision' | 'name' | 'description' | 'type' | 'status' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'source.version' | 'metadata.hidden' | 'metadata.alwaysActive' | 'metadata.schedulingModificationDisabled' | 'metadata.actionRemovalDisabled' | 'metadata.actionConditionsEditingDisabled' | '_createdDate' | '_updatedDate' | 'esbConfigurationId', value: any[]) => AutomationsQueryBuilder;
    /** @documentationMaturity preview */
    in: (propertyName: '_id' | 'revision' | 'name' | 'description' | 'type' | 'status' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'source.version' | 'metadata.hidden' | 'metadata.alwaysActive' | 'metadata.schedulingModificationDisabled' | 'metadata.actionRemovalDisabled' | 'metadata.actionConditionsEditingDisabled' | '_createdDate' | '_updatedDate' | 'esbConfigurationId', value: any) => AutomationsQueryBuilder;
    /** @documentationMaturity preview */
    exists: (propertyName: '_id' | 'revision' | 'name' | 'description' | 'type' | 'status' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'source.version' | 'metadata.hidden' | 'metadata.alwaysActive' | 'metadata.schedulingModificationDisabled' | 'metadata.actionRemovalDisabled' | 'metadata.actionConditionsEditingDisabled' | '_createdDate' | '_updatedDate' | 'esbConfigurationId', value: boolean) => AutomationsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    ascending: (...propertyNames: Array<'_id' | 'revision' | 'name' | 'description' | 'type' | 'status' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'source.version' | 'metadata.hidden' | 'metadata.alwaysActive' | 'metadata.schedulingModificationDisabled' | 'metadata.actionRemovalDisabled' | 'metadata.actionConditionsEditingDisabled' | '_createdDate' | '_updatedDate' | 'esbConfigurationId'>) => AutomationsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    descending: (...propertyNames: Array<'_id' | 'revision' | 'name' | 'description' | 'type' | 'status' | 'rule.trigger.appId' | 'rule.trigger.triggerKey' | 'rule.actions.id' | 'rule.actions.appId' | 'rule.actions.actionKey' | 'source.automationId' | 'source.appId' | 'source.componentId' | 'source.version' | 'metadata.hidden' | 'metadata.alwaysActive' | 'metadata.schedulingModificationDisabled' | 'metadata.actionRemovalDisabled' | 'metadata.actionConditionsEditingDisabled' | '_createdDate' | '_updatedDate' | 'esbConfigurationId'>) => AutomationsQueryBuilder;
    /** @param limit - Number of items to return, which is also the `pageSize` of the results object.
     * @documentationMaturity preview
     */
    limit: (limit: number) => AutomationsQueryBuilder;
    /** @param cursor - A pointer to specific record
     * @documentationMaturity preview
     */
    skipTo: (cursor: string) => AutomationsQueryBuilder;
    /** @documentationMaturity preview */
    find: () => Promise<AutomationsQueryResult>;
}
/**
 * Creates a new Automation
 * @param automation - Application Automation
 * @public
 * @documentationMaturity preview
 * @requiredField automation
 * @requiredField automation.name
 * @requiredField automation.rule
 * @requiredField automation.rule.actions
 * @requiredField automation.rule.actions.actionKey
 * @requiredField automation.rule.actions.appId
 * @requiredField automation.rule.trigger
 * @requiredField automation.rule.trigger.appId
 * @requiredField automation.rule.trigger.triggerKey
 * @permissionId AUTOMATIONS.OVERRIDE_APPLICATION_AUTOMATION
 * @applicableIdentity APP
 * @fqn com.wixpress.automations.service.AutomationsService.OverrideApplicationAutomation
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function overrideApplicationAutomation(automation: NonNullablePaths<Automation, `name` | `rule` | `rule.actions` | `rule.actions.${number}.actionKey` | `rule.actions.${number}.appId` | `rule.trigger` | `rule.trigger.appId` | `rule.trigger.triggerKey`>): Promise<NonNullablePaths<OverrideApplicationAutomationResponse, {
    [P in AutomationNonNullablePaths]: `automation.${P}`;
}[AutomationNonNullablePaths]>>;
/**
 * Validate Automation by Id
 * @param automationId - Automation ID
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.AUTOMATION_VALIDATE
 * @applicableIdentity APP
 * @fqn com.wixpress.automations.service.AutomationsService.ValidateAutomationById
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function validateAutomationById(automationId: string, options?: ValidateAutomationByIdOptions): Promise<NonNullablePaths<ValidateAutomationByIdResponse, `valid` | `triggerValidationErrors` | `triggerValidationErrors.${number}.configurationError.errorType` | `triggerValidationErrors.${number}.providerConfigurationError.message` | `triggerValidationErrors.${number}.providerConfigurationError.title` | `triggerValidationErrors.${number}.errorType` | `actionValidationInfo` | `actionValidationInfo.${number}.appId` | `actionValidationInfo.${number}.actionKey`>>;
interface ValidateAutomationByIdOptions {
    /** Automation type */
    automationType?: TypeWithLiterals;
}
/**
 * Validate Automation
 * @param automation - Automation to validate
 * @public
 * @documentationMaturity preview
 * @requiredField automation
 * @permissionId AUTOMATIONS.AUTOMATION_VALIDATE
 * @applicableIdentity APP
 * @fqn com.wixpress.automations.service.AutomationsService.ValidateAutomation
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function validateAutomation(automation: Automation): Promise<NonNullablePaths<ValidateAutomationResponse, `valid` | `triggerValidationErrors` | `triggerValidationErrors.${number}.configurationError.errorType` | `triggerValidationErrors.${number}.providerConfigurationError.message` | `triggerValidationErrors.${number}.providerConfigurationError.title` | `triggerValidationErrors.${number}.errorType` | `actionValidationInfo` | `actionValidationInfo.${number}.appId` | `actionValidationInfo.${number}.actionKey`>>;
/** @param automationId - Automation ID
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @applicableIdentity APP
 * @fqn com.wixpress.automations.service.AutomationsService.GetAutomationActivationStats
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function getAutomationActivationStats(automationId: string, options?: GetAutomationActivationStatsOptions): Promise<NonNullablePaths<GetAutomationActivationReportsResponse, `activationReports` | `activationReports.${number}.activationId` | `activationReports.${number}.requestId` | `activationReports.${number}.status`>>;
interface GetAutomationActivationStatsOptions {
    paging?: Paging;
    /** Fields projection - pass in the field key you want to get back */
    fields?: string[];
}
/**
 * Get actions quota information
 * @public
 * @documentationMaturity preview
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @applicableIdentity APP
 * @fqn com.wixpress.automations.service.AutomationsService.GetActionsQuotaInfo
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function getActionsQuotaInfo(): Promise<NonNullablePaths<GetActionsQuotaInfoResponse, `actionProviderQuotaInfo` | `actionProviderQuotaInfo.${number}.appId` | `actionProviderQuotaInfo.${number}.actionKey` | `actionProviderQuotaInfo.${number}.actionQuotaInfo.enforced`>>;
/**
 * Generate action input mapping from a template
 * @param appId - action app id
 * @public
 * @documentationMaturity preview
 * @requiredField appId
 * @requiredField options
 * @requiredField options.actionInputMappingTemplate
 * @requiredField options.actionKey
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @applicableIdentity APP
 * @fqn com.wixpress.automations.service.AutomationsService.GenerateActionInputMappingFromTemplate
 * @deprecated
 * @targetRemovalDate 2025-05-01
 */
declare function generateActionInputMappingFromTemplate(appId: string, options: NonNullablePaths<GenerateActionInputMappingFromTemplateOptions, `actionInputMappingTemplate` | `actionKey`>): Promise<GenerateActionInputMappingFromTemplateResponse>;
interface GenerateActionInputMappingFromTemplateOptions {
    /** the action key */
    actionKey: string;
    /** action input mapping template the action spi provider will generate input mapping from */
    actionInputMappingTemplate: Record<string, any> | null;
}

export { type Action, type ActionConfigurationError, ActionErrorType, type ActionErrorTypeWithLiterals, type ActionEvent, type ActionProviderQuotaInfo, type ActionQuotaInfo, type ActionValidationError, type ActionValidationErrorErrorOneOf, type ActionValidationInfo, type ActivationReport, ActivationStatus, type ActivationStatusWithLiterals, type AdditionalInfo, type ApplicationError, type Asset, type Automation, type AutomationCreatedEnvelope, type AutomationDeletedEnvelope, type AutomationDeletedWithEntityEnvelope, type AutomationMetadata, type AutomationUpdatedEnvelope, type AutomationUpdatedWithPreviousEntityEnvelope, type AutomationsQueryBuilder, type AutomationsQueryResult, type BaseEventMetadata, BlockType, type BlockTypeWithLiterals, type BulkActionMetadata, type BulkCreateApplicationAutomationRequest, type BulkCreateApplicationAutomationResponse, type BulkDeleteAutomationsRequest, type BulkDeleteAutomationsResponse, type CTA, type Condition, type ConditionBlock, type Conditions, type CreateAutomationRequest, type CreateAutomationResponse, type CursorPaging, type Cursors, type Debounce, type Delay, type DelayTypeOneOf, type DeleteAutomationOptions, type DeleteAutomationRequest, type DeleteAutomationResponse, type DeleteContext, DeleteStatus, type DeleteStatusWithLiterals, type DeletedWithEntity, Domain, type DomainEvent, type DomainEventBodyOneOf, type DomainWithLiterals, type Empty, type EntityCreatedEvent, type EntityDeletedEvent, type EntityUpdatedEvent, type EventMetadata, type ExtendedFields, type Filter, type GenerateActionInputMappingFromTemplateOptions, type GenerateActionInputMappingFromTemplateRequest, type GenerateActionInputMappingFromTemplateResponse, type GenerateApplicationAutomationFromCustomRequest, type GenerateApplicationAutomationFromCustomResponse, type GetActionsQuotaInfoRequest, type GetActionsQuotaInfoResponse, type GetApplicationAutomationRequest, type GetApplicationAutomationResponse, type GetAutomationActionSchemaRequest, type GetAutomationActionSchemaResponse, type GetAutomationActivationReportsRequest, type GetAutomationActivationReportsResponse, type GetAutomationActivationStatsOptions, type GetAutomationOptions, type GetAutomationRequest, type GetAutomationResponse, type IdentificationData, type IdentificationDataIdOneOf, type ItemMetadata, type MessageEnvelope, type MetaSiteSpecialEvent, type MetaSiteSpecialEventPayloadOneOf, type MigrationBulkCreateAutomations, type MigrationBulkCreateAutomationsRequest, type MigrationBulkCreateAutomationsResponse, type MigrationUpdateAutomation, type MigrationUpdateAutomationRequest, type MigrationUpdateAutomationResponse, type MigrationUpdateMigratedToV3AutomationRequest, type MigrationUpdateMigratedToV3AutomationResponse, Namespace, type NamespaceChanged, type NamespaceWithLiterals, type OdeditorAssigned, type OdeditorUnassigned, type Offset, type OffsetValueOneOf, type OverrideApplicationAutomationRequest, type OverrideApplicationAutomationResponse, type Paging, type PagingMetadata, type PagingMetadataV2, type PicassoAssigned, type PicassoUnassigned, type Plan, type ProviderConfigurationError, type QueryApplicationAutomationsRequest, type QueryApplicationAutomationsResponse, type QueryAutomationsOptions, type QueryAutomationsRequest, type QueryAutomationsResponse, type QueryV2, type QueryV2PagingMethodOneOf, type Quota, type QuotaInfo, type RateLimit, type RestoreInfo, type Rule, type ServiceProvisioned, type ServiceRemoved, type SiteCreated, SiteCreatedContext, type SiteCreatedContextWithLiterals, type SiteDeleted, type SiteHardDeleted, type SiteMarkedAsTemplate, type SiteMarkedAsWixSite, type SitePublished, type SitePurgedExternally, type SiteRenamed, type SiteTransferred, type SiteUndeleted, type SiteUnpublished, type SiteUrlChanged, SortOrder, type SortOrderWithLiterals, type Sorting, type Source, State, type StateWithLiterals, Status, type StatusWithLiterals, type StudioAssigned, type StudioUnassigned, type SyncApplicationAutomationsRequest, type SyncApplicationAutomationsResponse, type Trigger, type TriggerConfigurationError, TriggerErrorType, type TriggerErrorTypeWithLiterals, type TriggerValidationError, type TriggerValidationErrorErrorOneOf, TriggerValidationErrorValidationErrorType, type TriggerValidationErrorValidationErrorTypeWithLiterals, Type, type TypeWithLiterals, type Until, type UpdateApplicationAutomationConfigurationIdRequest, type UpdateApplicationAutomationConfigurationIdResponse, type UpdateApplicationAutomationToMigratedFromV1Request, type UpdateApplicationAutomationToMigratedFromV1Response, type UpdateAutomation, type UpdateAutomationRequest, type UpdateAutomationResponse, type UpdatedAutomationsWithEsb, type UpdatedWithPreviousEntity, type UpgradeCTA, type ValidateAutomationByIdOptions, type ValidateAutomationByIdRequest, type ValidateAutomationByIdResponse, type ValidateAutomationRequest, type ValidateAutomationResponse, ValidationErrorType, type ValidationErrorTypeWithLiterals, WebhookIdentityType, type WebhookIdentityTypeWithLiterals, createAutomation, deleteAutomation, generateActionInputMappingFromTemplate, getActionsQuotaInfo, getAutomation, getAutomationActivationStats, migrationUpdateAutomation, onAutomationCreated, onAutomationDeleted, onAutomationDeletedWithEntity, onAutomationUpdated, onAutomationUpdatedWithPreviousEntity, overrideApplicationAutomation, queryAutomations, updateAutomation, validateAutomation, validateAutomationById };
